# Module Index

- `magneticalc` - MagnetiCalc package initialization.
  - `About_Dialog` - About_Dialog module.
  - `API` - API module.
  - `Assert_Dialog` - Assert_Dialog module.
  - `Backend_CUDA` - Backend_CUDA module.
  - `Backend_JIT` - Backend_JIT module.
  - `Backend_Types` - Backend_Types module.
  - `CalculationThread` - CalculationThread module.
  - `CheckForUpdates_Dialog` - CheckForUpdates_Dialog module.
  - `Comparison_Types` - Comparison_Types module.
  - `ConditionalDecorator` - ConditionalDecorator module.
  - `Config` - Config module.
  - `Config_Group` - Config_Collection module.
  - `Constants` - Constants module.
  - `Constraint` - Constraint module.
  - `Constraint_Editor` - Constraint_Editor module.
  - `Debug` - Debug module.
  - `Display_Widget` - Display_Widget module.
  - `ExportContainer_Dialog` - ExportContainer_Dialog module.
  - `Field` - Field module.
  - `Field_Types` - Field_Types module.
  - `Field_Widget` - Field_Widget module.
  - `File_Menu` - File_Menu module.
  - `Format` - Format module.
  - `GUI` - GUI module.
  - `Help_Menu` - Help_Menu module.
  - `MagnetiCalc_Data` - MagnetiCalc_Data module.
  - `Menu` - Menu module.
  - `Metric` - Metric module.
  - `Metric_Presets` - Metric_Presets module.
  - `Metric_Widget` - Metric_Widget module.
  - `Model` - Model module.
  - `ModelAccess` - Model access module.
  - `Norm_Types` - Norm_Types module.
  - `Options_Menu` - Options_Menu module.
  - `OverridePadding_Dialog` - OverridePadding_Dialog module.
  - `Parameters` - Parameters module.
  - `Parameters_Widget` - Parameters_Widget module.
  - `Perspective_Presets` - Perspective_Presets module.
  - `Perspective_Widget` - Perspective_Widget module.
  - `Project` - Project module.
  - `QCheckboxConfig` - QCheckboxConfig module.
  - `QMessageBox2` - QMessageBox2 module.
  - `QTableView2` - QTableView2 module.
  - `QtWidgets2` - MagnetiCalc package initialization.
    - `QButtons` - QButtons module.
    - `QDialog2` - QDialog2 module.
    - `QDoubleSpinBox2` - QDoubleSpinBox2 module.
    - `QGroupBox2` - QGroupBox2 module.
    - `QHBoxLayout2` - QHBoxLayout2 module.
    - `QHLine` - QHLine module.
    - `QIconLabel` - QIconLabel module.
    - `QLabel2` - QLabel2 module.
    - `QLayouted` - QLayouted module.
    - `QPushButton2` - QPushButton2 module.
    - `QSaveAction` - QSaveAction module.
    - `QSliderFloat` - QSliderFloat module.
    - `QSpinBox2` - QSpinBox2 module.
    - `QTextBrowser2` - QTextBrowser2 module.
  - `SamplingVolume` - Sampling volume module.
  - `SamplingVolume_Widget` - SamplingVolume_Widget module.
  - `SidebarLeft` - SidebarLeft module.
  - `SidebarRight` - SidebarRight module.
  - `Statusbar` - Statusbar module.
  - `Theme` - Theme module.
  - `Usage_Dialog` - Usage_Dialog module.
  - `Validatable` - Validatable module.
  - `Version` - Version module.
  - `View_Menu` - View_Menu module.
  - `VisPyCanvas` - VisPyCanvas module.
  - `Wire` - Wire module.
  - `Wire_Menu` - Wire_Menu module.
  - `Wire_Presets` - Wire_Presets module.
  - `Wire_Widget` - Wire_Widget module.
  - `__main__` - MagnetiCalc main module.